@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 
-VERSION = (1, 3, 0)
+from __future__ import unicode_literals
+
+VERSION = (1, 4, 1)
 
 
 def get_version():
@@ -8,3 +10,5 @@ def get_version():
     return '%s.%s.%s' % (VERSION[0], VERSION[1], VERSION[2])
 
 __version__ = get_version()
+
+default_app_config = 'coop_bar.apps.CoopBarAppConfig'
